import globals from "globals";
import eslintPluginJasmine from "eslint-plugin-jasmine";
import eslintPluginProtractor from "eslint-plugin-protractor";

/**
 * @typedef {import("eslint").Linter.Config} Config
 */

/**
 * @param {Config} config
 * @returns {Config}
 */
function defineConfig(config) {
	return config;
}

const severity = {
	0: "off",
	1: "warn",
	2: "error",
};

function migrate(config) {
	for (const [rule, options] of Object.entries(config.rules)) {
		if (typeof options === "number") {
			config.rules[rule] = severity[options];
		}
	}
	return config;
}

const jasmineRecommended = migrate(eslintPluginJasmine.configs.recommended);
const protractorRecommended = eslintPluginProtractor.configs.recommended;

export default defineConfig({
	languageOptions: {
		globals: {
			...eslintPluginProtractor.environments.globals.globals,
			...globals.jasmine,
		},
	},

	plugins: {
		jasmine: eslintPluginJasmine,
		protractor: eslintPluginProtractor,
	},

	rules: {
		...jasmineRecommended.rules,
		...protractorRecommended.rules,
		"jasmine/new-line-before-expect": "off",
		"jasmine/no-disabled-tests": "warn",
		"jasmine/no-focused-tests": "warn",
		"jasmine/no-spec-dupes": ["error", "branch"],
	},
});
